==> chrome-devtools-frontend-1.0.861923.tgz: package/front_end/shell.js <==
// Copyright 2020 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import './Images/Images.js';
import './startup/startup.js';
import './dom_extension/dom_extension.js';
import './host/host-legacy.js';
import './protocol_client/protocol_client-legacy.js';
import './sdk/sdk-legacy.js';
import './ui/ui-legacy.js';
import './workspace/workspace-legacy.js';
import './bindings/bindings-legacy.js';
import './components/components-legacy.js';
import './persistence/persistence-legacy.js';
import './browser_sdk/browser_sdk.js';
import './extensions/extensions-legacy.js';
import './console_counters/console_counters-legacy.js';
import './sources/sources-meta.js';
import './profiler/profiler-meta.js';
import './console/console-meta.js';
import './coverage/coverage-meta.js';
import './changes/changes-meta.js';
import './input/input-meta.js';
import './linear_memory_inspector/linear_memory_inspector-meta.js';
import './settings/settings-meta.js';
import './protocol_monitor/protocol_monitor-meta.js';
import './persistence/persistence-meta.js';
import './browser_sdk/browser_sdk-meta.js';
import './main/main-meta.js';
import './perf_ui/perf_ui-meta.js';
import './quick_open/quick_open-meta.js';
import './sdk/sdk-meta.js';
import './source_frame/source_frame-meta.js';
import './console_counters/console_counters-meta.js';
import './object_ui/object_ui-meta.js';
// We generate the descriptors in this file, which depend on the runtime.

==> chrome-devtools-frontend-1.0.865074.tgz: package/front_end/shell.js <==
// Copyright 2020 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

import './Images/Images.js';
import './startup/startup.js';
import './dom_extension/dom_extension.js';
import './host/host-legacy.js';
import './protocol_client/protocol_client-legacy.js';
import './sdk/sdk-legacy.js';
import './ui/ui-legacy.js';
import './workspace/workspace-legacy.js';
import './bindings/bindings-legacy.js';
import './components/components-legacy.js';
import './persistence/persistence-legacy.js';
import './browser_sdk/browser_sdk.js';
import './extensions/extensions-legacy.js';
import './panels/console_counters/console_counters-legacy.js';
import './sources/sources-meta.js';
import './profiler/profiler-meta.js';
import './panels/console/console-meta.js';
import './panels/coverage/coverage-meta.js';
import './panels/changes/changes-meta.js';
import './input/input-meta.js';
import './linear_memory_inspector/linear_memory_inspector-meta.js';
import './settings/settings-meta.js';
import './protocol_monitor/protocol_monitor-meta.js';
import './persistence/persistence-meta.js';
import './browser_sdk/browser_sdk-meta.js';
import './main/main-meta.js';
import './perf_ui/perf_ui-meta.js';
import './quick_open/quick_open-meta.js';
import './sdk/sdk-meta.js';
import './source_frame/source_frame-meta.js';
import './panels/console_counters/console_counters-meta.js';
import './object_ui/object_ui-meta.js';
// We generate the descriptors in this file, which depend on the runtime.
